# steam2starbound
This utility copies the "contents.pak" files of mods from the steam workshop, to the starbound mods directory.

## Usage
`steam2starbound "*STEAM_LIBRARY_PATH*/steamapps/workshop/content/211820" "*STEAM_LIBRARY_PATH*/steamapps/common/Starbound/mods"`
